# Copyright 2016 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# [START app]
import logging

from google.appengine.api import app_identity
from google.appengine.api import urlfetch

from flask import Flask


APP_ID = app_identity.get_application_id()
FETCH_FLEX_URL = (
    "http://auth-test-flex-dot-{}.appspot-preview.com"
    .format(APP_ID))
FETCH_STANDARD_URL = (
    "http://auth-test-standard-dot-{}.appspot.com"
    .format(APP_ID))


app = Flask(__name__)


@app.route('/flex')
def flex():
    result = urlfetch.fetch(
        url=FETCH_FLEX_URL,
        follow_redirects=False,
        method=urlfetch.GET)
    return str(result.content)


@app.route('/standard')
def standard():
    result = urlfetch.fetch(
        url=FETCH_STANDARD_URL,
        follow_redirects=False,
        method=urlfetch.GET)
    return str(result.content)


@app.errorhandler(500)
def server_error(e):
    # Log the error and stacktrace.
    logging.exception('An error occurred during a request.')
    return 'An internal error occurred.', 500
# [END app]
